@@ -100,6 +100,7 @@ API_PATH = {
     "mentions":                "message/mentions",
     "message":                 "message/messages/{id}/",
     "messages":                "message/messages/",
+    "moderated":               "user/{user}/moderated_subreddits/",
     "moderator_messages":      "r/{subreddit}/message/moderator/",
     "moderator_unread":        "r/{subreddit}/message/moderator/unread/",
     "modmail_archive":         "api/mod/conversations/{id}/archive",
@@ -133,6 +134,9 @@ API_PATH = {
     "read_message":            "api/read_message/",
     "removal_comment_message": "api/v1/modactions/removal_comment_message",
     "removal_link_message":    "api/v1/modactions/removal_link_message",
+    "removal_reasons":         "api/v1/modactions/removal_reasons",
+    "removal_reason":          "api/v1/{subreddit}/removal_reasons/{id}",
+    "removal_reasons_list":    "api/v1/{subreddit}/removal_reasons",
     "remove":                  "api/remove/",
     "report":                  "api/report/",
     "rules":                   "r/{subreddit}/about/rules",
@@ -141,6 +145,7 @@ API_PATH = {
     "select_flair":            "r/{subreddit}/api/selectflair/",
     "sendreplies":             "api/sendreplies",
     "sent":                    "message/sent/",
+    "set_original_content":    "api/set_original_content",
     "setpermissions":          "r/{subreddit}/api/setpermissions/",
     "site_admin":              "api/site_admin/",
     "spoiler":                 "api/spoiler/",
@@ -183,6 +188,7 @@ API_PATH = {
     "upload_image":            "r/{subreddit}/api/upload_sr_img",
     "user":                    "user/{user}/",
     "user_about":              "user/{user}/about/",
+    "user_by_fullname":        "/api/user_data_by_account_ids",
     "user_flair":              "r/{subreddit}/api/user_flair_v2",
     "users_new":               "users/new",
     "users_popular":           "users/popular",
