@@ -1,22 +1,29 @@
 """Provide the Front class."""
+from typing import Dict, Generator, List, TypeVar, Union
+
 from ..const import API_PATH
-from .listing.generator import ListingGenerator
 from .base import PRAWBase
+from .listing.generator import ListingGenerator
 from .util import stream_generator
 
+Comment = TypeVar("Comment")
+Message = TypeVar("Message")
+
 
 class Inbox(PRAWBase):
     """Inbox is a Listing class that represents the Inbox."""
 
-    def all(self, **generator_kwargs):
-        """Return a ListingGenerator for all inbox comments and messages.
+    def all(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Union[Message, Comment], None, None]:
+        """Return a :class:`.ListingGenerator` for all inbox comments and messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         To output the type and ID of all items available via this listing do:
 
-        .. code:: python
+        .. code-block:: python
 
            for item in reddit.inbox.all(limit=None):
                print(repr(item))
@@ -26,7 +33,7 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["inbox"], **generator_kwargs
         )
 
-    def collapse(self, items):
+    def collapse(self, items: List[Message]):
         """Mark an inbox message as collapsed.
 
         :param items: A list containing instances of :class:`.Message`.
@@ -35,7 +42,7 @@ class Inbox(PRAWBase):
 
         For example, to collapse all unread Messages, try:
 
-        .. code:: python
+        .. code-block:: python
 
             from praw.models import Message
             unread_messages = []
@@ -54,15 +61,17 @@ class Inbox(PRAWBase):
             self._reddit.post(API_PATH["collapse"], data=data)
             items = items[25:]
 
-    def comment_replies(self, **generator_kwargs):
-        """Return a ListingGenerator for comment replies.
+    def comment_replies(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Comment, None, None]:
+        """Return a :class:`.ListingGenerator` for comment replies.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         To output the author of one request worth of comment replies try:
 
-        .. code:: python
+        .. code-block:: python
 
            for reply in reddit.inbox.comment_replies():
                print(reply.author)
@@ -72,7 +81,7 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["comment_replies"], **generator_kwargs
         )
 
-    def mark_read(self, items):
+    def mark_read(self, items: List[Union[Comment, Message]]):
         """Mark Comments or Messages as read.
 
         :param items: A list containing instances of :class:`.Comment` and/or
@@ -83,7 +92,7 @@ class Inbox(PRAWBase):
 
         For example, to mark all unread Messages as read, try:
 
-        .. code:: python
+        .. code-block:: python
 
             from praw.models import Message
             unread_messages = []
@@ -102,7 +111,7 @@ class Inbox(PRAWBase):
             self._reddit.post(API_PATH["read_message"], data=data)
             items = items[25:]
 
-    def mark_unread(self, items):
+    def mark_unread(self, items: List[Union[Comment, Message]]):
         """Unmark Comments or Messages as read.
 
         :param items: A list containing instances of :class:`.Comment` and/or
@@ -113,7 +122,7 @@ class Inbox(PRAWBase):
 
         For example, to mark the first 10 items as unread try:
 
-        .. code:: python
+        .. code-block:: python
 
             to_unread = list(reddit.inbox.all(limit=10))
             reddit.inbox.mark_unread(to_unread)
@@ -128,8 +137,10 @@ class Inbox(PRAWBase):
             self._reddit.post(API_PATH["unread_message"], data=data)
             items = items[25:]
 
-    def mentions(self, **generator_kwargs):
-        r"""Return a ListingGenerator for mentions.
+    def mentions(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Comment, None, None]:
+        r"""Return a :class:`.ListingGenerator` for mentions.
 
         A mention is :class:`.Comment` in which the authorized redditor is
         named in its body like ``/u/redditor_name``.
@@ -140,7 +151,7 @@ class Inbox(PRAWBase):
         For example, to output the author and body of the first 25 mentions
         try:
 
-        .. code:: python
+        .. code-block:: python
 
            for mention in reddit.inbox.mentions(limit=25):
                print('{}\n{}\n'.format(mention.author, mention.body))
@@ -150,14 +161,14 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["mentions"], **generator_kwargs
         )
 
-    def message(self, message_id):
+    def message(self, message_id: str) -> Message:
         """Return a Message corresponding to ``message_id``.
 
         :param message_id: The base36 id of a message.
 
         For example:
 
-        .. code:: python
+        .. code-block:: python
 
            message = reddit.inbox.message('7bnlgu')
 
@@ -169,15 +180,17 @@ class Inbox(PRAWBase):
             if message.id == message_id:
                 return message
 
-    def messages(self, **generator_kwargs):
-        """Return a ListingGenerator for inbox messages.
+    def messages(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Message, None, None]:
+        """Return a :class:`.ListingGenerator` for inbox messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         For example, to output the subject of the most recent 5 messages try:
 
-        .. code:: python
+        .. code-block:: python
 
            for message in reddit.inbox.messages(limit=5):
                print(message.subject)
@@ -187,8 +200,10 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["messages"], **generator_kwargs
         )
 
-    def sent(self, **generator_kwargs):
-        """Return a ListingGenerator for sent messages.
+    def sent(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Message, None, None]:
+        """Return a :class:`.ListingGenerator` for sent messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -196,7 +211,7 @@ class Inbox(PRAWBase):
         For example, to output the recipient of the most recent 15 messages
         try:
 
-        .. code:: python
+        .. code-block:: python
 
            for message in reddit.inbox.sent(limit=15):
                print(message.dest)
@@ -206,7 +221,9 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["sent"], **generator_kwargs
         )
 
-    def stream(self, **stream_options):
+    def stream(
+        self, **stream_options: Union[str, int, Dict[str, str]]
+    ) -> Generator[Union[Comment, Message], None, None]:
         """Yield new inbox items as they become available.
 
         Items are yielded oldest first. Up to 100 historical items will
@@ -216,7 +233,7 @@ class Inbox(PRAWBase):
 
         For example, to retrieve all new inbox items, try:
 
-        .. code:: python
+        .. code-block:: python
 
            for item in reddit.inbox.stream():
                print(item)
@@ -224,15 +241,17 @@ class Inbox(PRAWBase):
         """
         return stream_generator(self.unread, **stream_options)
 
-    def submission_replies(self, **generator_kwargs):
-        """Return a ListingGenerator for submission replies.
+    def submission_replies(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Comment, None, None]:
+        """Return a :class:`.ListingGenerator` for submission replies.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         To output the author of one request worth of submission replies try:
 
-        .. code:: python
+        .. code-block:: python
 
            for reply in reddit.inbox.submission_replies():
                print(reply.author)
@@ -242,7 +261,7 @@ class Inbox(PRAWBase):
             self._reddit, API_PATH["submission_replies"], **generator_kwargs
         )
 
-    def uncollapse(self, items):
+    def uncollapse(self, items: List[Message]):
         """Mark an inbox message as uncollapsed.
 
         :param items: A list containing instances of :class:`.Message`.
@@ -251,7 +270,7 @@ class Inbox(PRAWBase):
 
         For example, to uncollapse all unread Messages, try:
 
-        .. code:: python
+        .. code-block:: python
 
             from praw.models import Message
             unread_messages = []
@@ -270,8 +289,12 @@ class Inbox(PRAWBase):
             self._reddit.post(API_PATH["uncollapse"], data=data)
             items = items[25:]
 
-    def unread(self, mark_read=False, **generator_kwargs):
-        """Return a ListingGenerator for unread comments and messages.
+    def unread(
+        self,
+        mark_read: bool = False,
+        **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Union[Comment, Message], None, None]:
+        """Return a :class:`.ListingGenerator` for unread comments and messages.
 
         :param mark_read: Marks the inbox as read (default: False).
 
@@ -283,7 +306,7 @@ class Inbox(PRAWBase):
 
         For example, to output the author of unread comments try:
 
-        .. code:: python
+        .. code-block:: python
 
            from praw.models import Comment
            for item in reddit.inbox.unread(limit=None):
