@@ -1,8 +1,11 @@
 """Provide the ListingGenerator class."""
 from copy import deepcopy
+from typing import Any, Dict, Iterator, Optional, TypeVar
 
-from .listing import FlairListing
 from ..base import PRAWBase
+from .listing import FlairListing
+
+Reddit = TypeVar("Reddit")
 
 
 class ListingGenerator(PRAWBase):
@@ -15,7 +18,13 @@ class ListingGenerator(PRAWBase):
 
     """
 
-    def __init__(self, reddit, url, limit=100, params=None):
+    def __init__(
+        self,
+        reddit: Reddit,
+        url: str,
+        limit: int = 100,
+        params: Optional[Dict[str, str]] = None,
+    ):
         """Initialize a ListingGenerator instance.
 
         :param reddit: An instance of :class:`.Reddit`.
@@ -29,7 +38,7 @@ class ListingGenerator(PRAWBase):
             parameters to send with the request.
 
         """
-        super(ListingGenerator, self).__init__(reddit, _data=None)
+        super().__init__(reddit, _data=None)
         self._exhausted = False
         self._listing = None
         self._list_index = None
@@ -39,11 +48,11 @@ class ListingGenerator(PRAWBase):
         self.url = url
         self.yielded = 0
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[Any]:
         """Permit ListingGenerator to operate as an iterator."""
         return self
 
-    def __next__(self):
+    def __next__(self) -> Any:
         """Permit ListingGenerator to operate as a generator."""
         if self.limit is not None and self.yielded >= self.limit:
             raise StopIteration()
