@@ -1,4 +1,5 @@
 """Provide the BaseListingMixin class."""
+from typing import Any, Dict, Generator, Union
 from urllib.parse import urljoin
 
 from ...base import PRAWBase
@@ -28,8 +29,12 @@ class BaseListingMixin(PRAWBase):
                 )
             )
 
-    def controversial(self, time_filter="all", **generator_kwargs):
-        """Return a ListingGenerator for controversial submissions.
+    def controversial(
+        self,
+        time_filter: str = "all",
+        **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for controversial submissions.
 
         :param time_filter: Can be one of: all, day, hour, month, week, year
             (default: all).
@@ -41,7 +46,7 @@ class BaseListingMixin(PRAWBase):
 
         This method can be used like:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.domain('imgur.com').controversial('week')
            reddit.multireddit('samuraisam', 'programming').controversial('day')
@@ -56,15 +61,17 @@ class BaseListingMixin(PRAWBase):
         url = _prepare(self, generator_kwargs, "controversial")
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def hot(self, **generator_kwargs):
-        """Return a ListingGenerator for hot items.
+    def hot(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for hot items.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         This method can be used like:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.domain('imgur.com').hot()
            reddit.multireddit('samuraisam', 'programming').hot()
@@ -78,15 +85,17 @@ class BaseListingMixin(PRAWBase):
         url = _prepare(self, generator_kwargs, "hot")
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def new(self, **generator_kwargs):
-        """Return a ListingGenerator for new items.
+    def new(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for new items.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         This method can be used like:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.domain('imgur.com').new()
            reddit.multireddit('samuraisam', 'programming').new()
@@ -100,8 +109,12 @@ class BaseListingMixin(PRAWBase):
         url = _prepare(self, generator_kwargs, "new")
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def top(self, time_filter="all", **generator_kwargs):
-        """Return a ListingGenerator for top submissions.
+    def top(
+        self,
+        time_filter: str = "all",
+        **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for top submissions.
 
         :param time_filter: Can be one of: all, day, hour, month, week, year
             (default: all).
@@ -113,7 +126,7 @@ class BaseListingMixin(PRAWBase):
 
         This method can be used like:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.domain('imgur.com').top('week')
            reddit.multireddit('samuraisam', 'programming').top('day')
