@@ -1,4 +1,5 @@
 """Provide the RedditorListingMixin class."""
+from typing import Any, Dict, Generator, TypeVar, Union
 from urllib.parse import urljoin
 
 from ....util.cache import cachedproperty
@@ -6,18 +7,37 @@ from ..generator import ListingGenerator
 from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 
+Reddit = TypeVar("Reddit")
+
+
+class SubListing(BaseListingMixin):
+    """Helper class for generating :class:`.ListingGenerator` objects."""
+
+    def __init__(self, reddit: Reddit, base_path: str, subpath: str):
+        """Initialize a SubListing instance.
+
+        :param reddit: An instance of :class:`.Reddit`.
+        :param base_path: The path to the object up to this point.
+        :param subpath: The additional path to this sublisting.
+
+        """
+        super().__init__(reddit, _data=None)
+        self._listing_use_sort = True
+        self._reddit = reddit
+        self._path = urljoin(base_path, subpath)
+
 
 class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     """Adds additional methods pertaining to Redditor instances."""
 
     @cachedproperty
-    def comments(self):
+    def comments(self) -> SubListing:
         r"""Provide an instance of :class:`.SubListing` for comment access.
 
         For example, to output the first line of all new comments by
         ``/u/spez`` try:
 
-        .. code:: python
+        .. code-block:: python
 
            for comment in reddit.redditor('spez').comments.new(limit=None):
                print(comment.body.split('\n', 1)[0][:79])
@@ -26,13 +46,13 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
         return SubListing(self._reddit, self._path, "comments")
 
     @cachedproperty
-    def submissions(self):
+    def submissions(self) -> SubListing:
         """Provide an instance of :class:`.SubListing` for submission access.
 
         For example, to output the title's of top 100 of all time submissions
         for ``/u/spez`` try:
 
-        .. code:: python
+        .. code-block:: python
 
            for submission in reddit.redditor('spez').submissions.top('all'):
                print(submission.title)
@@ -40,8 +60,10 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
         """
         return SubListing(self._reddit, self._path, "submitted")
 
-    def downvoted(self, **generator_kwargs):
-        """Return a ListingGenerator for items the user has downvoted.
+    def downvoted(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for items the user has downvoted.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
         is not authorized to access the list. Note that because this function
@@ -56,8 +78,10 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
             self._reddit, urljoin(self._path, "downvoted"), **generator_kwargs
         )
 
-    def gildings(self, **generator_kwargs):
-        """Return a ListingGenerator for items the user has gilded.
+    def gildings(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for items the user has gilded.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
         is not authorized to access the list. Note that because this function
@@ -74,8 +98,10 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
             **generator_kwargs
         )
 
-    def hidden(self, **generator_kwargs):
-        """Return a ListingGenerator for items the user has hidden.
+    def hidden(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for items the user has hidden.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
         is not authorized to access the list. Note that because this function
@@ -90,8 +116,10 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
             self._reddit, urljoin(self._path, "hidden"), **generator_kwargs
         )
 
-    def saved(self, **generator_kwargs):
-        """Return a ListingGenerator for items the user has saved.
+    def saved(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for items the user has saved.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
         is not authorized to access the list. Note that because this function
@@ -106,8 +134,10 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
             self._reddit, urljoin(self._path, "saved"), **generator_kwargs
         )
 
-    def upvoted(self, **generator_kwargs):
-        """Return a ListingGenerator for items the user has upvoted.
+    def upvoted(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Any, None, None]:
+        """Return a :class:`.ListingGenerator` for items the user has upvoted.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
         is not authorized to access the list. Note that because this function
@@ -121,20 +151,3 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
         return ListingGenerator(
             self._reddit, urljoin(self._path, "upvoted"), **generator_kwargs
         )
-
-
-class SubListing(BaseListingMixin):
-    """Helper class for generating ListingGenerator objects."""
-
-    def __init__(self, reddit, base_path, subpath):
-        """Initialize a SubListing instance.
-
-        :param reddit: An instance of :class:`.Reddit`.
-        :param base_path: The path to the object up to this point.
-        :param subpath: The additional path to this sublisting.
-
-        """
-        super(SubListing, self).__init__(reddit, _data=None)
-        self._listing_use_sort = True
-        self._reddit = reddit
-        self._path = urljoin(base_path, subpath)
