@@ -1,15 +1,20 @@
 """Provide the RisingListingMixin class."""
+from typing import Dict, Generator, TypeVar, Union
 from urllib.parse import urljoin
 
 from ...base import PRAWBase
 from ..generator import ListingGenerator
 
+Submission = TypeVar("Submission")
+
 
 class RisingListingMixin(PRAWBase):
     """Mixes in the rising methods."""
 
-    def random_rising(self, **generator_kwargs):
-        """Return a ListingGenerator for random rising submissions.
+    def random_rising(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Submission, None, None]:
+        """Return a :class:`.ListingGenerator` for random rising submissions.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -21,8 +26,10 @@ class RisingListingMixin(PRAWBase):
             **generator_kwargs
         )
 
-    def rising(self, **generator_kwargs):
-        """Return a ListingGenerator for rising submissions.
+    def rising(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Submission, None, None]:
+        """Return a :class:`.ListingGenerator` for rising submissions.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
