@@ -1,12 +1,21 @@
 """Provide the LiveThread class."""
+from typing import Any, Dict, Generator, List, Optional, TypeVar, Union
+
 from ...const import API_PATH
 from ...util.cache import cachedproperty
-from ..listing.generator import ListingGenerator
 from ..list.redditor import RedditorList
+from ..listing.generator import ListingGenerator
 from .base import RedditBase
 from .mixins import FullnameMixin
 from .redditor import Redditor
 
+_LiveThread = TypeVar("_LiveThread")
+_LiveThreadContribution = TypeVar("_LiveThreadContribution")
+_LiveUpdate = TypeVar("_LiveUpdate")
+_LiveUpdateContribution = TypeVar("_LiveUpdateContribution")
+Reddit = TypeVar("Reddit")
+Submission = TypeVar("Submission")
+
 
 class LiveContributorRelationship:
     """Provide methods to interact with live threads' contributors."""
@@ -19,7 +28,7 @@ class LiveContributorRelationship:
             permissions = set(permissions)
         return ",".join("+{}".format(x) for x in permissions)
 
-    def __call__(self):
+    def __call__(self) -> List[Redditor]:
         """Return a :class:`.RedditorList` for live threads' contributors.
 
         Usage:
@@ -35,7 +44,7 @@ class LiveContributorRelationship:
         temp = self.thread._reddit.get(url)
         return temp if isinstance(temp, RedditorList) else temp[0]
 
-    def __init__(self, thread):
+    def __init__(self, thread: _LiveThread):
         """Create a :class:`.LiveContributorRelationship` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
@@ -61,7 +70,11 @@ class LiveContributorRelationship:
         url = API_PATH["live_accept_invite"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
-    def invite(self, redditor, permissions=None):
+    def invite(
+        self,
+        redditor: Union[str, Redditor],
+        permissions: Optional[List[str]] = None,
+    ):
         """Invite a redditor to be a contributor of the live thread.
 
         Raise :class:`praw.exceptions.APIException` if the invitation
@@ -110,7 +123,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_leave"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
-    def remove(self, redditor):
+    def remove(self, redditor: Union[str, Redditor]):
         """Remove the redditor from the live thread contributors.
 
         :param redditor: A redditor fullname (e.g., ``'t2_1w72'``) or
@@ -134,7 +147,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_remove_contrib"].format(id=self.thread.id)
         self.thread._reddit.post(url, data=data)
 
-    def remove_invite(self, redditor):
+    def remove_invite(self, redditor: Union[str, Redditor]):
         """Remove the invite for redditor.
 
         :param redditor: A redditor fullname (e.g., ``'t2_1w72'``) or
@@ -161,7 +174,11 @@ class LiveContributorRelationship:
         url = API_PATH["live_remove_invite"].format(id=self.thread.id)
         self.thread._reddit.post(url, data=data)
 
-    def update(self, redditor, permissions=None):
+    def update(
+        self,
+        redditor: Union[str, Redditor],
+        permissions: Optional[List[str]] = None,
+    ):
         """Update the contributor permissions for ``redditor``.
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
@@ -174,7 +191,7 @@ class LiveContributorRelationship:
 
         For example, to grant all permissions to the contributor, try:
 
-        .. code:: python
+        .. code-block:: python
 
            thread = reddit.live('ukaeu1ik4sw5')
            thread.contributor.update('spez')
@@ -182,13 +199,13 @@ class LiveContributorRelationship:
         To grant 'access' and 'edit' permissions (and to remove other
         permissions), try:
 
-        .. code:: python
+        .. code-block:: python
 
            thread.contributor.update('spez', ['access', 'edit'])
 
         To remove all permissions from the contributor, try:
 
-        .. code:: python
+        .. code-block:: python
 
            subreddit.moderator.update('spez', [])
 
@@ -201,7 +218,11 @@ class LiveContributorRelationship:
         }
         self.thread._reddit.post(url, data=data)
 
-    def update_invite(self, redditor, permissions=None):
+    def update_invite(
+        self,
+        redditor: Union[str, Redditor],
+        permissions: Optional[List[str]] = None,
+    ):
         """Update the contributor invite permissions for ``redditor``.
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
@@ -214,7 +235,7 @@ class LiveContributorRelationship:
 
         For example, to set all permissions to the invitation, try:
 
-        .. code:: python
+        .. code-block:: python
 
            thread = reddit.live('ukaeu1ik4sw5')
            thread.contributor.update_invite('spez')
@@ -222,13 +243,13 @@ class LiveContributorRelationship:
         To set 'access' and 'edit' permissions (and to remove other
         permissions) to the invitation, try:
 
-        .. code:: python
+        .. code-block:: python
 
            thread.contributor.update_invite('spez', ['access', 'edit'])
 
         To remove all permissions from the invitation, try:
 
-        .. code:: python
+        .. code-block:: python
 
            thread.contributor.update_invite('spez', [])
 
@@ -271,7 +292,7 @@ class LiveThread(RedditBase):
     STR_FIELD = "id"
 
     @cachedproperty
-    def contrib(self):
+    def contrib(self) -> _LiveThreadContribution:
         """Provide an instance of :class:`.LiveThreadContribution`.
 
         Usage:
@@ -285,7 +306,7 @@ class LiveThread(RedditBase):
         return LiveThreadContribution(self)
 
     @cachedproperty
-    def contributor(self):
+    def contributor(self) -> LiveContributorRelationship:
         """Provide an instance of :class:`.LiveContributorRelationship`.
 
         You can call the instance to get a list of contributors which is
@@ -303,7 +324,7 @@ class LiveThread(RedditBase):
         """
         return LiveContributorRelationship(self)
 
-    def __eq__(self, other):
+    def __eq__(self, other: Union[str, _LiveThread]) -> bool:
         """Return whether the other instance equals the current.
 
         .. note:: This comparison is case sensitive.
@@ -312,7 +333,7 @@ class LiveThread(RedditBase):
             return other == str(self)
         return isinstance(other, self.__class__) and str(self) == str(other)
 
-    def __getitem__(self, update_id):
+    def __getitem__(self, update_id: str) -> _LiveUpdate:
         """Return a lazy :class:`.LiveUpdate` instance.
 
         :param update_id: A live update ID, e.g.,
@@ -330,12 +351,17 @@ class LiveThread(RedditBase):
         """
         return LiveUpdate(self._reddit, self.id, update_id)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         """Return the hash of the current instance."""
         return hash(self.__class__.__name__) ^ hash(str(self))
 
     def __init__(
-        self, reddit, id=None, _data=None  # pylint: disable=redefined-builtin
+        self,
+        reddit: Reddit,
+        id: Optional[str] = None,
+        _data: Optional[
+            Dict[str, Any]
+        ] = None,  # pylint: disable=redefined-builtin
     ):
         """Initialize a lazy :class:`.LiveThread` instance.
 
@@ -344,7 +370,7 @@ class LiveThread(RedditBase):
         """
         if bool(id) == bool(_data):
             raise TypeError("Either `id` or `_data` must be provided.")
-        super(LiveThread, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         if id:
             self.id = id
 
@@ -363,7 +389,9 @@ class LiveThread(RedditBase):
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
-    def discussions(self, **generator_kwargs):
+    def discussions(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[Submission, None, None]:
         """Get submissions linking to the thread.
 
         :param generator_kwargs: keyword arguments passed to
@@ -371,6 +399,9 @@ class LiveThread(RedditBase):
         :returns: A :class:`.ListingGenerator` object which yields
             :class:`.Submission` object.
 
+        Additional keyword arguments are passed in the initialization of
+        :class:`.ListingGenerator`.
+
         Usage:
 
         .. code-block:: python
@@ -383,7 +414,7 @@ class LiveThread(RedditBase):
         url = API_PATH["live_discussions"].format(id=self.id)
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
-    def report(self, type):  # pylint: disable=redefined-builtin
+    def report(self, type: str):  # pylint: disable=redefined-builtin
         """Report the thread violating the Reddit rules.
 
         :param type: One of ``'spam'``, ``'vote-manipulation'``,
@@ -401,7 +432,9 @@ class LiveThread(RedditBase):
         url = API_PATH["live_report"].format(id=self.id)
         self._reddit.post(url, data={"type": type})
 
-    def updates(self, **generator_kwargs):
+    def updates(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[_LiveUpdate, None, None]:
         """Return a :class:`.ListingGenerator` yields :class:`.LiveUpdate` s.
 
         :param generator_kwargs: keyword arguments passed to
@@ -409,6 +442,9 @@ class LiveThread(RedditBase):
         :returns: A :class:`.ListingGenerator` object which yields
             :class:`.LiveUpdate` object.
 
+        Additional keyword arguments are passed in the initialization of
+        :class:`.ListingGenerator`.
+
         Usage:
 
         .. code-block:: python
@@ -428,7 +464,7 @@ class LiveThread(RedditBase):
 class LiveThreadContribution:
     """Provides a set of contribution functions to a LiveThread."""
 
-    def __init__(self, thread):
+    def __init__(self, thread: LiveThread):
         """Create an instance of :class:`.LiveThreadContribution`.
 
         :param thread: An instance of :class:`.LiveThread`.
@@ -444,10 +480,10 @@ class LiveThreadContribution:
         """
         self.thread = thread
 
-    def add(self, body):
+    def add(self, body: str):
         """Add an update to the live thread.
 
-        :param body: The markdown formatted content for the update.
+        :param body: The Markdown formatted content for the update.
 
         Usage:
 
@@ -476,11 +512,11 @@ class LiveThreadContribution:
 
     def update(
         self,
-        title=None,
-        description=None,
-        nsfw=None,
-        resources=None,
-        **other_settings
+        title: Optional[str] = None,
+        description: Optional[str] = None,
+        nsfw: Optional[bool] = None,
+        resources: Optional[str] = None,
+        **other_settings: Optional[str]
     ):
         """Update settings of the live thread.
 
@@ -568,7 +604,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
     _kind = "LiveUpdate"
 
     @cachedproperty
-    def contrib(self):
+    def contrib(self) -> _LiveUpdateContribution:
         """Provide an instance of :class:`.LiveUpdateContribution`.
 
         Usage:
@@ -583,11 +619,17 @@ class LiveUpdate(FullnameMixin, RedditBase):
         return LiveUpdateContribution(self)
 
     @property
-    def thread(self):
+    def thread(self) -> LiveThread:
         """Return :class:`.LiveThread` object the update object belongs to."""
         return self._thread
 
-    def __init__(self, reddit, thread_id=None, update_id=None, _data=None):
+    def __init__(
+        self,
+        reddit: Reddit,
+        thread_id: Optional[str] = None,
+        update_id: Optional[str] = None,
+        _data: Optional[Dict[str, Any]] = None,
+    ):
         """Initialize a lazy :class:`.LiveUpdate` instance.
 
         Either ``thread_id`` and ``update_id``, or ``_data`` must be
@@ -612,10 +654,10 @@ class LiveUpdate(FullnameMixin, RedditBase):
             # Since _data (part of JSON returned from reddit) have no
             # thread ID, self._thread must be set by the caller of
             # LiveUpdate(). See the code of LiveThread.updates() for example.
-            super(LiveUpdate, self).__init__(reddit, _data=_data)
+            super().__init__(reddit, _data=_data)
             self._fetched = True
         elif thread_id and update_id:
-            super(LiveUpdate, self).__init__(reddit, _data=None)
+            super().__init__(reddit, _data=None)
             self._thread = LiveThread(self._reddit, thread_id)
             self.id = update_id
         else:
@@ -624,11 +666,11 @@ class LiveUpdate(FullnameMixin, RedditBase):
                 "`_data` must be provided."
             )
 
-    def __setattr__(self, attribute, value):
+    def __setattr__(self, attribute: str, value: Any):
         """Objectify author."""
         if attribute == "author":
             value = Redditor(self._reddit, name=value)
-        super(LiveUpdate, self).__setattr__(attribute, value)
+        super().__setattr__(attribute, value)
 
     def _fetch(self):
         url = API_PATH["live_focus"].format(
@@ -642,7 +684,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
 class LiveUpdateContribution:
     """Provides a set of contribution functions to LiveUpdate."""
 
-    def __init__(self, update):
+    def __init__(self, update: LiveUpdate):
         """Create an instance of :class:`.LiveUpdateContribution`.
 
         :param update: An instance of :class:`.LiveUpdate`.
