@@ -1,10 +1,14 @@
 """Provide the Message class."""
+from typing import Any, Dict, TypeVar
+
 from ...const import API_PATH
 from .base import RedditBase
 from .mixins import FullnameMixin, InboxableMixin, ReplyableMixin
 from .redditor import Redditor
 from .subreddit import Subreddit
 
+Reddit = TypeVar("Reddit")
+
 
 class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
     """A class for private messages.
@@ -42,7 +46,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
     STR_FIELD = "id"
 
     @classmethod
-    def parse(cls, data, reddit):
+    def parse(cls, data: Dict[str, Any], reddit: Reddit):
         """Return an instance of Message or SubredditMessage from ``data``.
 
         :param data: The structured data.
@@ -76,9 +80,9 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
         """Return the class's kind."""
         return self._reddit.config.kinds["message"]
 
-    def __init__(self, reddit, _data):
+    def __init__(self, reddit: Reddit, _data: Dict[str, Any]):
         """Construct an instance of the Message object."""
-        super(Message, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         self._fetched = True
 
     def delete(self):
@@ -95,7 +99,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
 class SubredditMessage(Message):
     """A class for messages to a subreddit."""
 
-    def mute(self, _unmute=False):
+    def mute(self):
         """Mute the sender of this SubredditMessage."""
         self._reddit.post(API_PATH["mute_sender"], data={"id": self.fullname})
 
