@@ -11,28 +11,28 @@ class MessageableMixin:
 
         :param subject: The subject of the message.
         :param message: The message content.
-        :param from_subreddit: A Subreddit instance or string to send the
-            message from. When provided, messages are sent from the subreddit
-            rather than from the authenticated user. Note that the
-            authenticated user must be a moderator of the subreddit and have
-            mail permissions.
+        :param from_subreddit: A :class:`~.Subreddit` instance or string to
+            send the message from. When provided, messages are sent from
+            the subreddit rather than from the authenticated user.
+            Note that the authenticated user must be a moderator of the
+            subreddit and have the ``mail`` moderator permission.
 
-        For example, to send a private message to ``/u/spez``, try:
+        For example, to send a private message to ``u/spez``, try:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.redditor('spez').message('TEST', 'test message from PRAW')
 
         To send a message to ``u/spez`` from the moderators of ``r/test`` try:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.redditor('spez').message('TEST', 'test message from r/test',
                                            from_subreddit='test')
 
-        To send a message to the moderators of ``/r/test``, try:
+        To send a message to the moderators of ``r/test``, try:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('test').message('TEST', 'test PM from PRAW')
 
