@@ -10,9 +10,12 @@ class ReportableMixin:
 
         :param reason: The reason for reporting.
 
+        Raises :class:`.APIException` if ``reason`` is longer than 100
+        characters.
+
         Example usage:
 
-        .. code:: python
+        .. code-block:: python
 
            submission = reddit.submission(id='5or86n')
            submission.report('report reason')
