@@ -8,12 +8,13 @@ class SavableMixin:
     def save(self, category=None):
         """Save the object.
 
-        :param category: (Gold) The category to save to. If your user does not
-            have gold this value is ignored by Reddit (default: None).
+        :param category: (Premium) The category to save to. If your user does
+            not have Reddit Premium this value is ignored by Reddit
+            (default: ``None``).
 
         Example usage:
 
-        .. code:: python
+        .. code-block:: python
 
            submission = reddit.submission(id='5or86n')
            submission.save(category="view later")
@@ -33,7 +34,7 @@ class SavableMixin:
 
         Example usage:
 
-        .. code:: python
+        .. code-block:: python
 
            submission = reddit.submission(id='5or86n')
            submission.unsave()
