@@ -1,6 +1,7 @@
 """Provide the Multireddit class."""
-from json import dumps
 import re
+from json import dumps
+from typing import Any, Dict, List, Optional, TypeVar, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -9,10 +10,15 @@ from .base import RedditBase
 from .redditor import Redditor
 from .subreddit import Subreddit, SubredditStream
 
+_Multireddit = TypeVar("_Multireddit")
+Reddit = TypeVar("Reddit")
+
 
 class Multireddit(SubredditListingMixin, RedditBase):
     r"""A class for users' Multireddits.
 
+    This is referred to as a Custom Feed on the Reddit UI.
+
     **Typical Attributes**
 
     This table describes attributes that typically belong to objects of this
@@ -48,7 +54,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
     RE_INVALID = re.compile(r"[\W_]+", re.UNICODE)
 
     @staticmethod
-    def sluggify(title):
+    def sluggify(title: str):
         """Return a slug version of the title.
 
         :param title: The title to make a slug of.
@@ -65,22 +71,21 @@ class Multireddit(SubredditListingMixin, RedditBase):
         return title or "_"
 
     @cachedproperty
-    def stream(self):
+    def stream(self) -> SubredditStream:
         """Provide an instance of :class:`.SubredditStream`.
 
         Streams can be used to indefinitely retrieve new comments made to a
-        subreddit, like:
+        multireddit, like:
 
-        .. code:: python
+        .. code-block:: python
 
            for comment in reddit.multireddit('spez', 'fun').stream.comments():
                print(comment)
 
         Additionally, new submissions can be retrieved via the stream. In the
-        following example all submissions are fetched via the special subreddit
-        ``all``:
+        following example all new submissions to the multireddit are fetched:
 
-        .. code:: python
+        .. code-block:: python
 
            for submission in reddit.multireddit('bboe',
                                                 'games').stream.submissions():
@@ -89,10 +94,10 @@ class Multireddit(SubredditListingMixin, RedditBase):
         """
         return SubredditStream(self)
 
-    def __init__(self, reddit, _data):
+    def __init__(self, reddit: Reddit, _data: Dict[str, Any]):
         """Construct an instance of the Multireddit object."""
         self.path = None
-        super(Multireddit, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         self._author = Redditor(reddit, self.path.split("/", 3)[2])
         self._path = API_PATH["multireddit"].format(
             multi=self.name, user=self._author
@@ -122,7 +127,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
-    def add(self, subreddit):
+    def add(self, subreddit: Subreddit):
         """Add a subreddit to this multireddit.
 
         :param subreddit: The subreddit to add to this multi.
@@ -136,7 +141,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
         )
         self._reset_attributes("subreddits")
 
-    def copy(self, display_name=None):
+    def copy(self, display_name: Optional[str] = None) -> _Multireddit:
         """Copy this multireddit and return the new multireddit.
 
         :param display_name: (optional) The display name for the copied
@@ -166,7 +171,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
         )
         self._reddit.request("DELETE", path)
 
-    def remove(self, subreddit):
+    def remove(self, subreddit: Subreddit):
         """Remove a subreddit from this multireddit.
 
         :param subreddit: The subreddit to remove from this multi.
@@ -180,27 +185,19 @@ class Multireddit(SubredditListingMixin, RedditBase):
         )
         self._reset_attributes("subreddits")
 
-    def rename(self, display_name):
-        """Rename this multireddit.
-
-        :param display_name: The new display name for this multireddit. Reddit
-            will generate the ``name`` field from this display name.
-
-        """
-        data = {"from": self.path, "display_name": display_name}
-        updated = self._reddit.post(API_PATH["multireddit_rename"], data=data)
-        self.__dict__.update(updated.__dict__)
-
-    def update(self, **updated_settings):
+    def update(
+        self, **updated_settings: Union[str, List[Union[str, Subreddit]]]
+    ):
         """Update this multireddit.
 
         Keyword arguments are passed for settings that should be updated. They
         can any of:
 
-        :param display_name: The display name for this multireddit.
+        :param display_name: The display name for this multireddit. Must be no
+            longer than 50 characters.
         :param subreddits: Subreddits for this multireddit.
         :param description_md: Description for this multireddit, formatted in
-            markdown.
+            Markdown.
         :param icon_name: Can be one of: ``art and design``, ``ask``,
             ``books``, ``business``, ``cars``, ``comics``, ``cute animals``,
             ``diy``, ``entertainment``, ``food and drink``, ``funny``,
