@@ -1,5 +1,6 @@
 """Provide the Redditor class."""
 from json import dumps
+from typing import Any, Dict, Generator, List, Optional, TypeVar, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -8,6 +9,15 @@ from ..util import stream_generator
 from .base import RedditBase
 from .mixins import FullnameMixin, MessageableMixin
 
+_Redditor = TypeVar("_Redditor")
+_RedditorStream = TypeVar("_RedditorStream")
+Comment = TypeVar("Comment")
+Multireddit = TypeVar("Multireddit")
+Reddit = TypeVar("Reddit")
+Submission = TypeVar("Submission")
+Subreddit = TypeVar("Subreddit")
+Trophy = TypeVar("Trophy")
+
 
 class Redditor(
     MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
@@ -42,7 +52,7 @@ class Redditor(
     ``is_mod``                           Whether or not the Redditor mods any
                                          subreddits.
     ``is_gold``                          Whether or not the Redditor has active
-                                         gold status.
+                                         Reddit Premium status.
     ``link_karma``                       The link karma for the Redditor.
     ``name``                             The Redditor's username.
     ``subreddit``                        If the Redditor has created a
@@ -74,13 +84,13 @@ class Redditor(
         return cls(reddit, data)
 
     @cachedproperty
-    def stream(self):
+    def stream(self) -> _RedditorStream:
         """Provide an instance of :class:`.RedditorStream`.
 
         Streams can be used to indefinitely retrieve new comments made by a
         redditor, like:
 
-        .. code:: python
+        .. code-block:: python
 
            for comment in reddit.redditor('spez').stream.comments():
                print(comment)
@@ -89,7 +99,7 @@ class Redditor(
         following example all submissions are fetched via the redditor
         ``spez``:
 
-        .. code:: python
+        .. code-block:: python
 
            for submission in reddit.redditor('spez').stream.submissions():
                print(submission)
@@ -102,26 +112,50 @@ class Redditor(
         """Return the class's kind."""
         return self._reddit.config.kinds["redditor"]
 
-    def __init__(self, reddit, name=None, _data=None):
+    @property
+    def _path(self):
+        return API_PATH["user"].format(user=self)
+
+    def __init__(
+        self,
+        reddit: Reddit,
+        name: Optional[str] = None,
+        fullname: Optional[str] = None,
+        _data: Optional[Dict[str, Any]] = None,
+    ):
         """Initialize a Redditor instance.
 
         :param reddit: An instance of :class:`~.Reddit`.
         :param name: The name of the redditor.
+        :param fullname: The fullname of the redditor, starting with ``t2_``.
+
+        Exactly one of ``name``, ``fullname`` or ``_data`` must be provided.
 
         """
-        if bool(name) == bool(_data):
-            raise TypeError("Either `name` or `_data` must be provided.")
+        if [name, fullname, _data].count(None) != 2:
+            raise TypeError(
+                "Exactly one of `name`, `fullname`, or `_data` must be "
+                "provided."
+            )
         if _data:
             assert (
                 isinstance(_data, dict) and "name" in _data
             ), "Please file a bug with PRAW"
-        super(Redditor, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         self._listing_use_sort = True
         if name:
             self.name = name
-        self._path = API_PATH["user"].format(user=self)
+        elif fullname:
+            self._fullname = fullname
+
+    def _fetch_username(self, fullname):
+        return self._reddit.get(
+            API_PATH["user_by_fullname"], params={"ids": fullname}
+        )[fullname]["name"]
 
     def _fetch_info(self):
+        if hasattr(self, "_fullname"):
+            self.name = self._fetch_username(self._fullname)
         return ("user_about", {"user": self.name}, None)
 
     def _fetch_data(self):
@@ -146,27 +180,27 @@ class Redditor(
             API_PATH["block_user"], params={"account_id": self.fullname}
         )
 
-    def friend(self, note=None):
+    def friend(self, note: str = None):
         """Friend the Redditor.
 
         :param note: A note to save along with the relationship. Requires
-            reddit Gold (default: None).
+            Reddit Premium (default: None).
 
         Calling this method subsequent times will update the note.
 
         """
         self._friend("PUT", data={"note": note} if note else {})
 
-    def friend_info(self):
+    def friend_info(self) -> _Redditor:
         """Return a Redditor instance with specific friend-related attributes.
 
         :returns: A :class:`.Redditor` instance with fields ``date``, ``id``,
-            and possibly ``note`` if the authenticated user has reddit Gold.
+            and possibly ``note`` if the authenticated user has Reddit Premium.
 
         """
         return self._reddit.get(API_PATH["friend_v1"].format(user=self))
 
-    def gild(self, months=1):
+    def gild(self, months: int = 1):
         """Gild the Redditor.
 
         :param months: Specifies the number of months to gild up to 36
@@ -180,11 +214,39 @@ class Redditor(
             data={"months": months},
         )
 
-    def multireddits(self):
+    def moderated(self) -> List[Subreddit]:
+        """Return a list of the redditor's moderated subreddits.
+
+        :returns: A ``list`` of :class:`~praw.models.Subreddit` objects.
+            Return ``[]`` if the redditor has no moderated subreddits.
+
+        .. note:: The redditor's own user profile subreddit will not be
+           returned, but other user profile subreddits they moderate
+           will be returned.
+
+        Usage:
+
+        .. code-block:: python
+
+            for subreddit in reddit.redditor('spez').moderated():
+                print(subreddit.display_name)
+                print(subreddit.title)
+
+        """
+        modded_data = self._reddit.get(API_PATH["moderated"].format(user=self))
+        if "data" not in modded_data:
+            return []
+        else:
+            subreddits = [
+                self._reddit.subreddit(x["sr"]) for x in modded_data["data"]
+            ]
+            return subreddits
+
+    def multireddits(self) -> List[Multireddit]:
         """Return a list of the redditor's public multireddits."""
         return self._reddit.get(API_PATH["multireddit_user"].format(user=self))
 
-    def trophies(self):
+    def trophies(self) -> List[Trophy]:
         """Return a list of the redditor's trophies.
 
         :returns: A ``list`` of :class:`~praw.models.Trophy` objects.
@@ -194,7 +256,7 @@ class Redditor(
 
         Usage:
 
-        .. code:: python
+        .. code-block:: python
 
             for trophy in reddit.redditor('spez').trophies():
                 print(trophy.name)
@@ -218,10 +280,10 @@ class Redditor(
         self._friend(method="DELETE", data={"id": str(self)})
 
 
-class RedditorStream(object):
+class RedditorStream:
     """Provides submission and comment streams."""
 
-    def __init__(self, redditor):
+    def __init__(self, redditor: Redditor):
         """Create a RedditorStream instance.
 
         :param redditor: The redditor associated with the streams.
@@ -229,7 +291,9 @@ class RedditorStream(object):
         """
         self.redditor = redditor
 
-    def comments(self, **stream_options):
+    def comments(
+        self, **stream_options: Union[str, int, Dict[str, str]]
+    ) -> Generator[Comment, None, None]:
         """Yield new comments as they become available.
 
         Comments are yielded oldest first. Up to 100 historical comments will
@@ -240,7 +304,7 @@ class RedditorStream(object):
         For example, to retrieve all new comments made by redditor ``spez``,
         try:
 
-        .. code:: python
+        .. code-block:: python
 
            for comment in reddit.redditor('spez').stream.comments():
                print(comment)
@@ -248,7 +312,9 @@ class RedditorStream(object):
         """
         return stream_generator(self.redditor.comments.new, **stream_options)
 
-    def submissions(self, **stream_options):
+    def submissions(
+        self, **stream_options: Union[str, int, Dict[str, str]]
+    ) -> Generator[Submission, None, None]:
         """Yield new submissions as they become available.
 
         Submissions are yielded oldest first. Up to 100 historical submissions
@@ -259,7 +325,7 @@ class RedditorStream(object):
         For example to retrieve all new submissions made by redditor
         ``spez``, try:
 
-        .. code:: python
+        .. code-block:: python
 
            for submission in reddit.redditor('spez').stream.submissions():
                print(submission)
