@@ -1,7 +1,7 @@
 """Provide classes related to widgets."""
 
 import os.path
-from json import dumps, JSONEncoder
+from json import JSONEncoder, dumps
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -294,7 +294,7 @@ class SubredditWidgets(PRAWBase):
         self.subreddit = subreddit
         self.progressive_images = False
 
-        super(SubredditWidgets, self).__init__(subreddit._reddit, {})
+        super().__init__(subreddit._reddit, {})
 
     def __repr__(self):
         """Return an object initialization representation of the object."""
@@ -309,7 +309,7 @@ class SubredditWidgets(PRAWBase):
         )
 
         self._raw_items = data.pop("items")
-        super(SubredditWidgets, self).__init__(self.subreddit._reddit, data)
+        super().__init__(self.subreddit._reddit, data)
 
         cached_property_names = [
             "id_card",
@@ -948,7 +948,7 @@ class Widget(PRAWBase):
         """Initialize an instance of the class."""
         self.subreddit = ""  # in case it isn't in _data
         self.id = ""  # in case it isn't in _data
-        super(Widget, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         self._mod = None
 
 
@@ -1269,7 +1269,7 @@ class CustomWidget(Widget):
         _data["imageData"] = [
             ImageData(reddit, data) for data in _data.pop("imageData")
         ]
-        super(CustomWidget, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
 
 
 class IDCard(Widget):
@@ -1514,7 +1514,7 @@ class ModeratorsWidget(Widget, BaseList):
         if self.CHILD_ATTRIBUTE not in _data:
             # .mod.update() sometimes returns payload without 'mods' field
             _data[self.CHILD_ATTRIBUTE] = []
-        super(ModeratorsWidget, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
 
 
 class PostFlairWidget(Widget, BaseList):
@@ -1649,7 +1649,7 @@ class RulesWidget(Widget, BaseList):
         if self.CHILD_ATTRIBUTE not in _data:
             # .mod.update() sometimes returns payload without 'data' field
             _data[self.CHILD_ATTRIBUTE] = []
-        super(RulesWidget, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
 
 
 class TextArea(Widget):
