@@ -1,10 +1,101 @@
 """Provide the WikiPage class."""
+from typing import Any, Dict, Generator, Optional, TypeVar, Union
+
 from ...const import API_PATH
 from ...util.cache import cachedproperty
 from ..listing.generator import ListingGenerator
 from .base import RedditBase
 from .redditor import Redditor
 
+_WikiPage = TypeVar("_WikiPage")
+Reddit = TypeVar("Reddit")
+Subreddit = TypeVar("Subreddit")
+
+
+class WikiPageModeration:
+    """Provides a set of moderation functions for a WikiPage."""
+
+    def __init__(self, wikipage: _WikiPage):
+        """Create a WikiPageModeration instance.
+
+        :param wikipage: The wikipage to moderate.
+
+        """
+        self.wikipage = wikipage
+
+    def add(self, redditor: Redditor):
+        """Add an editor to this WikiPage.
+
+        :param redditor: A redditor name (e.g., ``'spez'``) or
+            :class:`~.Redditor` instance.
+
+        To add ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
+
+        .. code-block:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
+
+        """
+        data = {"page": self.wikipage.name, "username": str(redditor)}
+        url = API_PATH["wiki_page_editor"].format(
+            subreddit=self.wikipage.subreddit, method="add"
+        )
+        self.wikipage._reddit.post(url, data=data)
+
+    def remove(self, redditor: Redditor):
+        """Remove an editor from this WikiPage.
+
+        :param redditor: A redditor name (e.g., ``'spez'``) or
+            :class:`~.Redditor` instance.
+
+        To remove ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
+
+        .. code-block:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.remove('spez')
+
+        """
+        data = {"page": self.wikipage.name, "username": str(redditor)}
+        url = API_PATH["wiki_page_editor"].format(
+            subreddit=self.wikipage.subreddit, method="del"
+        )
+        self.wikipage._reddit.post(url, data=data)
+
+    def settings(self) -> Dict[str, Any]:
+        """Return the settings for this WikiPage."""
+        url = API_PATH["wiki_page_settings"].format(
+            subreddit=self.wikipage.subreddit, page=self.wikipage.name
+        )
+        return self.wikipage._reddit.get(url)["data"]
+
+    def update(
+        self, listed: bool, permlevel: int, **other_settings: Any
+    ) -> Dict[str, Any]:
+        """Update the settings for this WikiPage.
+
+        :param listed: (boolean) Show this page on page list.
+        :param permlevel: (int) Who can edit this page? (0) use subreddit wiki
+            permissions, (1) only approved wiki contributors for this page may
+            edit (see :meth:`.WikiPageModeration.add`), (2) only mods may edit
+            and view
+        :param other_settings: Additional keyword arguments to pass.
+        :returns: The updated WikiPage settings.
+
+        To set the wikipage ``'praw_test'`` in ``'/r/test'`` to mod only and
+          disable it from showing in the page list, try:
+
+        .. code-block:: python
+
+           reddit.subreddit('test').wiki['praw_test'].mod.update(listed=False,
+                                                                 permlevel=2)
+
+        """
+        other_settings.update({"listed": listed, "permlevel": permlevel})
+        url = API_PATH["wiki_page_settings"].format(
+            subreddit=self.wikipage.subreddit, page=self.wikipage.name
+        )
+        return self.wikipage._reddit.post(url, data=other_settings)["data"]
+
 
 class WikiPage(RedditBase):
     """An individual WikiPage object.
@@ -51,18 +142,25 @@ class WikiPage(RedditBase):
             yield revision
 
     @cachedproperty
-    def mod(self):
+    def mod(self) -> WikiPageModeration:
         """Provide an instance of :class:`.WikiPageModeration`."""
         return WikiPageModeration(self)
 
-    def __eq__(self, other):
+    def __eq__(self, other: _WikiPage):
         """Return whether the other instance equals the current."""
         return (
             isinstance(other, self.__class__)
             and str(self).lower() == str(other).lower()
         )
 
-    def __init__(self, reddit, subreddit, name, revision=None, _data=None):
+    def __init__(
+        self,
+        reddit: Reddit,
+        subreddit: Subreddit,
+        name: str,
+        revision: Optional[str] = None,
+        _data: Optional[Dict[str, Any]] = None,
+    ):
         """Construct an instance of the WikiPage object.
 
         :param revision: A specific revision ID to fetch. By default, fetches
@@ -72,15 +170,15 @@ class WikiPage(RedditBase):
         self.name = name
         self._revision = revision
         self.subreddit = subreddit
-        super(WikiPage, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
         return "{}(subreddit={!r}, name={!r})".format(
             self.__class__.__name__, self.subreddit, self.name
         )
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return a string representation of the instance."""
         return "{}/{}".format(self.subreddit, self.name)
 
@@ -106,10 +204,12 @@ class WikiPage(RedditBase):
         self.__dict__.update(data)
         self._fetched = True
 
-    def edit(self, content, reason=None, **other_settings):
+    def edit(
+        self, content: str, reason: Optional[str] = None, **other_settings: Any
+    ):
         """Edit this WikiPage's contents.
 
-        :param content: The updated markdown content of the page.
+        :param content: The updated Markdown content of the page.
         :param reason: (Optional) The reason for the revision.
         :param other_settings: Additional keyword arguments to pass.
 
@@ -122,12 +222,12 @@ class WikiPage(RedditBase):
             data=other_settings,
         )
 
-    def revision(self, revision):
+    def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
         To view revision ``[ID]`` of ``'praw_test'`` in ``'/r/test'``:
 
-        .. code:: python
+        .. code-block:: python
 
            page = reddit.subreddit('test').wiki['praw_test'].revision('[ID]')
 
@@ -136,22 +236,24 @@ class WikiPage(RedditBase):
             self.subreddit._reddit, self.subreddit, self.name, revision
         )
 
-    def revisions(self, **generator_kwargs):
-        """Return a generator for page revisions.
+    def revisions(
+        self, **generator_kwargs: Union[str, int, Dict[str, str]]
+    ) -> Generator[_WikiPage, None, None]:
+        """Return a :class:`.ListingGenerator` for page revisions.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
         To view the wiki revisions for ``'praw_test'`` in ``'/r/test'`` try:
 
-        .. code:: python
+        .. code-block:: python
 
            for item in reddit.subreddit('test').wiki['praw_test'].revisions():
                print(item)
 
         To get :class:`.WikiPage` objects for each revision:
 
-        .. code:: python
+        .. code-block:: python
 
            for item in reddit.subreddit('test').wiki['praw_test'].revisions():
                print(item['page'])
@@ -161,86 +263,3 @@ class WikiPage(RedditBase):
             subreddit=self.subreddit, page=self.name
         )
         return self._revision_generator(self.subreddit, url, generator_kwargs)
-
-
-class WikiPageModeration:
-    """Provides a set of moderation functions for a WikiPage."""
-
-    def __init__(self, wikipage):
-        """Create a WikiPageModeration instance.
-
-        :param wikipage: The wikipage to moderate.
-
-        """
-        self.wikipage = wikipage
-
-    def add(self, redditor):
-        """Add an editor to this WikiPage.
-
-        :param redditor: A redditor name (e.g., ``'spez'``) or
-            :class:`~.Redditor` instance.
-
-        To add ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
-
-        .. code:: python
-
-           reddit.subreddit('test').wiki['praw_test'].mod.add('spez')
-
-        """
-        data = {"page": self.wikipage.name, "username": str(redditor)}
-        url = API_PATH["wiki_page_editor"].format(
-            subreddit=self.wikipage.subreddit, method="add"
-        )
-        self.wikipage._reddit.post(url, data=data)
-
-    def remove(self, redditor):
-        """Remove an editor from this WikiPage.
-
-        :param redditor: A redditor name (e.g., ``'spez'``) or
-            :class:`~.Redditor` instance.
-
-        To remove ``'spez'`` as an editor on the wikipage ``'praw_test'`` try:
-
-        .. code:: python
-
-           reddit.subreddit('test').wiki['praw_test'].mod.remove('spez')
-
-        """
-        data = {"page": self.wikipage.name, "username": str(redditor)}
-        url = API_PATH["wiki_page_editor"].format(
-            subreddit=self.wikipage.subreddit, method="del"
-        )
-        self.wikipage._reddit.post(url, data=data)
-
-    def settings(self):
-        """Return the settings for this WikiPage."""
-        url = API_PATH["wiki_page_settings"].format(
-            subreddit=self.wikipage.subreddit, page=self.wikipage.name
-        )
-        return self.wikipage._reddit.get(url)["data"]
-
-    def update(self, listed, permlevel, **other_settings):
-        """Update the settings for this WikiPage.
-
-        :param listed: (boolean) Show this page on page list.
-        :param permlevel: (int) Who can edit this page? (0) use subreddit wiki
-            permissions, (1) only approved wiki contributors for this page may
-            edit (see :meth:`.WikiPageModeration.add`), (2) only mods may edit
-            and view
-        :param other_settings: Additional keyword arguments to pass.
-        :returns: The updated WikiPage settings.
-
-        To set the wikipage ``'praw_test'`` in ``'/r/test'`` to mod only and
-          disable it from showing in the page list, try:
-
-        .. code:: python
-
-           reddit.subreddit('test').wiki['praw_test'].mod.update(listed=False,
-                                                                 permlevel=2)
-
-        """
-        other_settings.update({"listed": listed, "permlevel": permlevel})
-        url = API_PATH["wiki_page_settings"].format(
-            subreddit=self.wikipage.subreddit, page=self.wikipage.name
-        )
-        return self.wikipage._reddit.post(url, data=other_settings)["data"]
