@@ -1,14 +1,8 @@
 """Provide the Reddit class."""
+import configparser
 import os
 from itertools import islice
-
-try:
-    from update_checker import update_check
-
-    UPDATE_CHECKER_MISSING = False
-except ImportError:  # pragma: no cover
-    UPDATE_CHECKER_MISSING = True
-
+from typing import IO, Any, Dict, Generator, Optional, Sequence, Type, Union
 
 from prawcore import (
     Authorizer,
@@ -23,15 +17,27 @@ from prawcore import (
 )
 
 from . import models
-from .compat import configparser, string_types
 from .config import Config
-from .const import __version__, API_PATH, USER_AGENT_FORMAT
+from .const import API_PATH, USER_AGENT_FORMAT, __version__
 from .exceptions import ClientException
 from .objector import Objector
 
+try:
+    from update_checker import update_check
 
-class Reddit(object):
-    """The Reddit class provides convenient access to reddit's API.
+    UPDATE_CHECKER_MISSING = False
+except ImportError:  # pragma: no cover
+    UPDATE_CHECKER_MISSING = True
+
+
+Comment = models.Comment
+Redditor = models.Redditor
+Submission = models.Submission
+Subreddit = models.Subreddit
+
+
+class Reddit:
+    """The Reddit class provides convenient access to Reddit's API.
 
     Instances of this class are the gateway to interacting with Reddit's API
     through PRAW. The canonical way to obtain an instance of this class is via:
@@ -55,12 +61,12 @@ class Reddit(object):
         return value
 
     @property
-    def read_only(self):
+    def read_only(self) -> bool:
         """Return True when using the ReadOnlyAuthorizer."""
         return self._core == self._read_only_core
 
     @read_only.setter
-    def read_only(self, value):
+    def read_only(self, value: bool) -> None:
         """Set or unset the use of the ReadOnlyAuthorizer.
 
         Raise :class:`ClientException` when attempting to unset ``read_only``
@@ -86,18 +92,18 @@ class Reddit(object):
 
     def __init__(
         self,
-        site_name=None,
-        requestor_class=None,
-        requestor_kwargs=None,
-        **config_settings
-    ):
+        site_name: str = None,
+        requestor_class: Optional[Type[Requestor]] = None,
+        requestor_kwargs: Dict[str, Any] = None,
+        **config_settings: str
+    ):  # noqa: D207, D301
         """Initialize a Reddit instance.
 
         :param site_name: The name of a section in your ``praw.ini`` file from
             which to load settings from. This parameter, in tandem with an
             appropriately configured ``praw.ini``, file is useful if you wish
             to easily save credentials for different applications, or
-            communicate with other servers running reddit. If ``site_name`` is
+            communicate with other servers running Reddit. If ``site_name`` is
             ``None``, then the site name will be looked for in the environment
             variable praw_site. If it is not found there, the DEFAULT site will
             be used.
@@ -107,7 +113,7 @@ class Reddit(object):
             used to initialize the requestor (default: None).
 
         Additional keyword arguments will be used to initialize the
-        :class`.Config` object. This can be used to specify configuration
+        :class:`.Config` object. This can be used to specify configuration
         settings during instantiation of the :class:`.Reddit` instance. For
         more details please see :ref:`configuration`.
 
@@ -118,9 +124,13 @@ class Reddit(object):
         * user_agent
 
         The ``requestor_class`` and ``requestor_kwargs`` allow for
-        customization of the requestor :class`.Reddit` will use. This allows,
+        customization of the requestor :class:`.Reddit` will use. This allows,
         e.g., easily adding behavior to the requestor or wrapping its
-        :class`Session` in a caching layer. Example usage:
+        |Session|_ in a caching layer. Example usage:
+
+        .. |Session| replace:: ``Session``
+        .. _Session: https://2.python-requests.org/en/master/api/\
+#requests.Session
 
         .. code-block:: python
 
@@ -407,8 +417,8 @@ class Reddit(object):
 
     def comment(
         self,  # pylint: disable=invalid-name
-        id=None,  # pylint: disable=redefined-builtin
-        url=None,
+        id: Optional[str] = None,  # pylint: disable=redefined-builtin
+        url: Optional[str] = None,
     ):
         """Return a lazy instance of :class:`~.Comment` for ``id``.
 
@@ -423,7 +433,7 @@ class Reddit(object):
         """
         return models.Comment(self, id=id, url=url)
 
-    def domain(self, domain):
+    def domain(self, domain: str):
         """Return an instance of :class:`.DomainListing`.
 
         :param domain: The domain to obtain submission listings for.
@@ -431,7 +441,9 @@ class Reddit(object):
         """
         return models.DomainListing(self, domain)
 
-    def get(self, path, params=None):
+    def get(
+        self, path: str, params: Optional[Union[str, Dict[str, str]]] = None
+    ):
         """Return parsed objects returned from a GET request to ``path``.
 
         :param path: The path to fetch.
@@ -442,7 +454,11 @@ class Reddit(object):
         data = self.request("GET", path, params=params)
         return self._objector.objectify(data)
 
-    def info(self, fullnames=None, url=None):
+    def info(
+        self,
+        fullnames: Optional[Sequence[str]] = None,
+        url: Optional[str] = None,
+    ) -> Generator[Union[Subreddit, Comment, Submission], None, None]:
         """Fetch information about each item in ``fullnames`` or from ``url``.
 
         :param fullnames: A list of fullnames for comments, submissions, and/or
@@ -473,7 +489,7 @@ class Reddit(object):
             )
 
         if fullnames is not None:
-            if isinstance(fullnames, string_types):
+            if isinstance(fullnames, str):
                 raise TypeError("`fullnames` must be a non-str iterable.")
 
             def generator(fullnames):
@@ -496,7 +512,13 @@ class Reddit(object):
 
         return generator(url)
 
-    def patch(self, path, data=None):
+    def patch(
+        self,
+        path: str,
+        data: Optional[
+            Union[Dict[str, Union[str, Any]], bytes, IO, str]
+        ] = None,
+    ) -> Any:
         """Return parsed objects returned from a PATCH request to ``path``.
 
         :param path: The path to fetch.
@@ -507,7 +529,15 @@ class Reddit(object):
         data = self.request("PATCH", path, data=data)
         return self._objector.objectify(data)
 
-    def post(self, path, data=None, files=None, params=None):
+    def post(
+        self,
+        path: str,
+        data: Optional[
+            Union[Dict[str, Union[str, Any]], bytes, IO, str]
+        ] = None,
+        files: Optional[Dict[str, IO]] = None,
+        params: Optional[Union[str, Dict[str, str]]] = None,
+    ) -> Any:
         """Return parsed objects returned from a POST request to ``path``.
 
         :param path: The path to fetch.
@@ -524,7 +554,13 @@ class Reddit(object):
         )
         return self._objector.objectify(data)
 
-    def put(self, path, data=None):
+    def put(
+        self,
+        path: str,
+        data: Optional[
+            Union[Dict[str, Union[str, Any]], bytes, IO, str]
+        ] = None,
+    ):
         """Return parsed objects returned from a PUT request to ``path``.
 
         :param path: The path to fetch.
@@ -535,7 +571,7 @@ class Reddit(object):
         data = self.request("PUT", path, data=data)
         return self._objector.objectify(data)
 
-    def random_subreddit(self, nsfw=False):
+    def random_subreddit(self, nsfw: bool = False) -> Subreddit:
         """Return a random lazy instance of :class:`~.Subreddit`.
 
         :param nsfw: Return a random NSFW (not safe for work) subreddit
@@ -552,15 +588,29 @@ class Reddit(object):
             path = redirect.path
         return models.Subreddit(self, path.split("/")[2])
 
-    def redditor(self, name):
-        """Return a lazy instance of :class:`~.Redditor` for ``name``.
+    def redditor(
+        self, name: Optional[str] = None, fullname: Optional[str] = None
+    ) -> Redditor:
+        """Return a lazy instance of :class:`~.Redditor`.
 
         :param name: The name of the redditor.
+        :param fullname: The fullname of the redditor, starting with ``t2_``.
+
+        Either ``name`` or ``fullname`` can be provided, but not both.
 
         """
-        return models.Redditor(self, name)
+        return models.Redditor(self, name=name, fullname=fullname)
 
-    def request(self, method, path, params=None, data=None, files=None):
+    def request(
+        self,
+        method: str,
+        path: str,
+        params: Optional[Union[str, Dict[str, str]]] = None,
+        data: Optional[
+            Union[Dict[str, Union[str, Any]], bytes, IO, str]
+        ] = None,
+        files: Optional[Dict[str, IO]] = None,
+    ) -> Any:
         """Return the parsed JSON data returned from a request to URL.
 
         :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
@@ -578,11 +628,11 @@ class Reddit(object):
         )
 
     def submission(  # pylint: disable=invalid-name,redefined-builtin
-        self, id=None, url=None
-    ):
+        self, id: Optional[str] = None, url: Optional[str] = None
+    ) -> Submission:
         """Return a lazy instance of :class:`~.Submission`.
 
-        :param id: A reddit base36 submission ID, e.g., ``2gmzqe``.
+        :param id: A Reddit base36 submission ID, e.g., ``2gmzqe``.
         :param url: A URL supported by
             :meth:`~praw.models.Submission.id_from_url`.`.
 
